@@ -5,6 +5,10 @@ def md5_hash(text):
     return hashlib.md5(text.encode('utf-8')).hexdigest()
 
 
+def sha256hash(text):
+    return hashlib.sha256(text.encode('utf-8')).hexdigest()
+
+
 def window(tokens, size=3):
     return [(tokens[i: i + size], tokens[i + size])
             for i in range(0, len(tokens) - size, 1)]
@@ -22,3 +26,13 @@ def offset_by_one(x, sequence_length=3):
     sl = sequence_length
     return [(x[i:i + sl], x[i + 1:i + sl + 1])
             for i in range(0, len(x) - sl - 1, sl)]
+
+
+def num_words(text: str):
+    """
+    Counts the number of words using whitespace as delimiter.
+
+    :param text: Sentence
+    :return: Number of words
+    """
+    return len(text.split())
